@@ -1,6 +1,6 @@
 package Dist::Zilla;
 {
-  $Dist::Zilla::VERSION = '5.000'; # TRIAL
+  $Dist::Zilla::VERSION = '5.001'; # TRIAL
 }
 # ABSTRACT: distribution builder; installer not included!
 use Moose 0.92; # role composition fixes
@@ -16,6 +16,7 @@ use Dist::Zilla::Types qw(License);
 
 use Log::Dispatchouli 1.100712; # proxy_loggers, quiet_fatal
 use Path::Class;
+use Path::Tiny;
 use List::Util qw(first);
 use Software::License 0.101370; # meta2_name
 use String::RewritePrefix;
@@ -499,13 +500,7 @@ sub _write_out_file {
 
   Carp::croak("attempted to write $to multiple times") if -e $to;
 
-  # This is needed, or \n is translated to \r\n on win32.
-  # Maybe :raw:utf8 is needed, but not sure.
-  #     -- Kentnl - 2010-06-10
-  open my $out_fh, '>:raw', "$to" or die "couldn't open $to to write: $!";
-
-  print { $out_fh } $file->encoded_content;
-  close $out_fh or die "error closing $to: $!";
+  path("$to")->spew_raw( $file->encoded_content );
   chmod $file->mode, "$to" or die "couldn't chmod $to: $!";
 }
 
@@ -564,7 +559,7 @@ Dist::Zilla - distribution builder; installer not included!
 
 =head1 VERSION
 
-version 5.000
+version 5.001
 
 =head1 DESCRIPTION
 
